"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*---------------------------------------------------------------------------------------------
 * Copyright (c) Bentley Systems, Incorporated. All rights reserved.
 * See LICENSE.md in the project root for license terms and full copyright notice.
 *--------------------------------------------------------------------------------------------*/
const apollo_client_1 = require("apollo-client");
const getErrorText_1 = require("../../util/getErrorText");
const i18n_1 = require("../../util/i18n");
const graphQLError = new Error("GRAPHQL_ERROR_1");
const networkError401 = new Error("NETWORK_ERROR_401");
networkError401.result = { errors: [{ extensions: { code: "401" } }] };
const networkErrorOther = new Error("NETWORK_ERROR_OTHER");
networkErrorOther.result = { errors: [{ message: "OTHER_NETWORK_ERROR" }] };
const networkErrorUnknown = new Error("NETWORK_ERROR_UNKNOWN");
const otherError = new Error("OTHER_ERROR");
describe("getErrorText", () => {
    it("return first GraphQLError message if there is one", () => {
        const error = new apollo_client_1.ApolloError({
            graphQLErrors: [graphQLError],
            networkError: networkErrorOther,
        });
        const test = getErrorText_1.getErrorText(error);
        expect(test).toEqual(graphQLError.message);
    });
    it("return networkError 401 message if first code is 401", () => {
        const error = new apollo_client_1.ApolloError({
            networkError: networkError401,
        });
        const test = getErrorText_1.getErrorText(error);
        expect(test).toEqual(i18n_1.iTwinErrorI18n.t("GraphQl.errors.unauthorizedError"));
    });
    it("return networkError result message if first code is not 401", () => {
        const error = new apollo_client_1.ApolloError({
            networkError: networkErrorOther,
        });
        const test = getErrorText_1.getErrorText(error);
        expect(test).toEqual("OTHER_NETWORK_ERROR");
    });
    it("return networkError message no result is present", () => {
        const error = new apollo_client_1.ApolloError({
            networkError: networkErrorUnknown,
        });
        const test = getErrorText_1.getErrorText(error);
        expect(test).toEqual(expect.stringContaining("NETWORK_ERROR_UNKNOWN"));
    });
    it("return Error message for normal errors", () => {
        const test = getErrorText_1.getErrorText(otherError);
        expect(test).toEqual("OTHER_ERROR");
    });
    it("return defaultError if no other error can be found", () => {
        const error = new apollo_client_1.ApolloError({});
        const test = getErrorText_1.getErrorText(error);
        expect(test).toEqual(i18n_1.iTwinErrorI18n.t("GraphQl.errors.defaultError"));
    });
});
//# sourceMappingURL=getErrorText.test.js.map